@@ -30,6 +30,8 @@ class TestSnappy:
     #     assert False
             
     testdata = [
+        
+        #### -> Testing for Mixed hostnames and ip addresses
         (["172.31.255.50", "172.31.255.20"], "Passed", 2),
         (["172.31.255.50", "172.31.255.20", "lin_jump_pub_01"], "Passed", 3),
         (["win_ad_01", "win_jump_pub_01", "lin_jump_pub_01"], "Passed", 3),
@@ -39,6 +41,12 @@ class TestSnappy:
         (["win_jump_pub_01", "10.0.0.0", "winlin_jump_pub_01"], "The following instances could not be retrieved: ['10.0.0.0', 'winlin_jump_pub_01']", 0),
         (["172.31.255.30", "172.31.255.50", "winlin_jump_pub_01"], "The following instances could not be retrieved: ['winlin_jump_pub_01']", 0),
         (["win_jump_pub_01", "10.0.0.0"], "The following instances could not be retrieved: ['10.0.0.0']", 0),
+        
+        #### -> Testing for Duplicates
+        (["172.31.255.50", "172.31.255.50", "172.31.255.20"], "Passed", 2),
+        (["172.31.255.50", "172.31.255.50", "172.31.255.50"], "Passed", 1),
+        (["lin_jump_pub_01", "172.31.255.30", "172.31.255.30"], "Passed", 1),
+        (["lin_jump_pub_01", "172.31.255.30", "172.31.255.20"], "Passed", 2),
     ]
     @pytest.mark.parametrize("test_data,expected_result,expected_size", testdata)
     def test_snappy_initialization(self,test_data,expected_result,expected_size):
@@ -54,6 +62,6 @@ class TestSnappy:
         # Assert
         assert result == expected_result
         
-        if result == "Passed":
+        if result == "Passed":                
             assert len(snappy.instances) == expected_size
         
\ No newline at end of file
